<?php

/*
Virtuemart / CB integration
Ben Jones / e-motion design 2006-2008
e-motion.com.au

Main plugin class

Changelog:
0.1.13 Update for Joomla 1.5.6, Community Builder 1.1, Virtuemart 1.1.2
0.1.12 Fixed default value of 'show title' parameter
       Fixed vmIsAdminMode undefined error
0.1.11 ENCODE_KEY not _ENCODE_KEY (Thanks Jim Idle)
       Disabled postRegoLogin function, was causing issues with activation
                         Fixed for shopper group issue, several code fixed  (Thanks Laurelle)
                         Thanks to Mark Jackson for this release
0.1.10 Added portugese and brazilian_portuguese languages (thanks to Shafik Mahomad)
       CB rego form can be included inside a VM page, alterations made to _showVirtuemartInfo function
       New version CB/Joomla login issue fixed
       Removed admin-specific options from the user tab (use VM to edit these)
       Using VM_SECRET/ENCODE_KEY from main VM config file
0.1.9  After registration, try to login (optional setting)
       If logging-in, can return to previous page
0.1.8  *Really* fixed localisation bug
0.1.7  Fixed localisation bug with plugin-specific strings
       Made virtuemart fields optional - required/optional
       Made registration fields optinal - hide/show
0.1.6  Use same _VIRTUEMART_SECRET as other VM files
       Show tab description if in edit mode
       Don't show break if hiding title
       Added localisation ability
0.1.5  Fixed notice on post-reg page
       Fixed installer problem
0.1.4  Added option to show/hide shipping address
       Set default values for parameters
       Added optional gap below output section
       Re-fill info on reload of rego page
       Takes rego page title from tab title
0.1.3  Country now required, state not required
       Admin can alter users 'permissions' (for shop)
       Admin can alter 'customer number'
       Admin can alter 'shopper group'
0.1.2  Added user title info
       Tidied post-rego notices
       Edit shipping address in admin section workaround
       Show break if title hidden
       Bank account info working
0.1.1  Fixed rego bug
0.1              First release
*/

// Standard Joomla security check
defined( '_VALID_MOS' ) or die( 'Direct Access to this location is not allowed.' );

// Register CB callbacks
$_PLUGINS->registerFunction( 'onAfterDeleteUser', 'userDeleteTab','getVirtuemartTab' );

// Include our language file (if exists!)
$defaultLanguage = 'english';
$currentLanguage = $GLOBALS['mosConfig_lang'];
$languagePrefix = $GLOBALS['mosConfig_absolute_path'] . '/components/com_comprofiler/plugin/user/plug_virtuemart/';
$currentLanguageFile = $languagePrefix . 'lang/'.$currentLanguage.'.php';
$defaultLanguageFile = $languagePrefix . 'lang/'.$defaultLanguage.'.php';
if ( file_exists( $currentLanguageFile ) ) {
        include( $currentLanguageFile );
} else {
        include( $defaultLanguageFile );
}

// Define some file locations we need to include
global $mosConfig_absolute_path , $mosConfig_lang;

DEFINE( '_VIRTUEMART_FILE_PERM' , $mosConfig_absolute_path . '/administrator/components/com_virtuemart/classes/ps_perm.php' );
DEFINE( '_VIRTUEMART_FILE_HTML' , $mosConfig_absolute_path . '/administrator/components/com_virtuemart/classes/ps_html.php' );
DEFINE( '_VIRTUEMART_FILE_MAIN' , $mosConfig_absolute_path . '/administrator/components/com_virtuemart/classes/ps_main.php' );
DEFINE( '_VIRTUEMART_FILE_MAINFRAME' , $mosConfig_absolute_path . '/administrator/components/com_virtuemart/classes/mainframe.class.php' );
DEFINE( '_VIRTUEMART_FILE_SHOPPER_GROUP' , $mosConfig_absolute_path . '/administrator/components/com_virtuemart/classes/ps_shopper_group.php' );
DEFINE( '_VIRTUEMART_FILE_ABSTRACT_OBJECT' , $mosConfig_absolute_path . '/administrator/components/com_virtuemart/classes/vmAbstractObject.class.php' );
DEFINE( '_VIRTUEMART_FILE_USER' , $mosConfig_absolute_path . '/administrator/components/com_virtuemart/classes/ps_user.php' );
DEFINE( '_VIRTUEMART_FILE_DATABASE' , $mosConfig_absolute_path . '/administrator/components/com_virtuemart/classes/ps_database.php' );
DEFINE( '_VIRTUEMART_FILE_LANGUAGE' , $mosConfig_absolute_path . '/administrator/components/com_virtuemart/classes/language.class.php' );
//DEFINE( '_VIRTUEMART_FILE_ENGLISH' , $mosConfig_absolute_path . '/administrator/components/com_virtuemart/languages/'. $mosConfig_lang .'.php' );
DEFINE( '_VIRTUEMART_FILE_CONFIG' , $mosConfig_absolute_path . '/administrator/components/com_virtuemart/virtuemart.cfg.php' );

DEFINE( '_VIRTUEMART_TITLE' , 'Virtuemart' );

class getVirtuemartTab extends cbTabHandler {
	
        /**
        * Constructor
        */      
        function getVirtuemartTab() {
                $this->cbTabHandler();
        }

        /**
        * Generates the HTML to display the user edit tab
        * @param object tab reflecting the tab database entry
        * @param object mosUser reflecting the user being displayed
        * @param int 1 for front-end, 2 for back-end
        * @returns mixed : either string HTML for tab content, or false if ErrorMSG generated
        */
        function getEditTab( $tab, $user, $ui) {
                if ( !$this->_checkVirtuemartInstalled() ) return null;
                return $this->_showVirtuemartInfo( $user , $tab );
        }

        /**
        * Saves the user edit tab postdata into the tab's permanent storage
        * @param object tab reflecting the tab database entry
        * @param object mosUser reflecting the user being displayed
        * @param int 1 for front-end, 2 for back-end
        * @param array _POST data for saving edited tab content as generated with getEditTab
        * @returns mixed : either string HTML for tab content, or false if ErrorMSG generated
        */
        function saveEditTab($tab, $user, $ui, $postdata) {
                if ( !$this->_checkVirtuemartInstalled() ) return null;
                $this->_saveVirtuemartInfo( $user );
        }
        
        /**
        * Generates the HTML to display the registration tab/area
        * @param object tab reflecting the tab database entry
        * @param object mosUser reflecting the user being displayed (here null)
        * @param int 1 for front-end, 2 for back-end
        * @return mixed : either string HTML for tab content, or false if ErrorMSG generated
        */
        function getDisplayRegistration($tab, $user, $ui) {
                if ( !$this->_checkVirtuemartInstalled() ) return null;
                return $this->_showVirtuemartInfo( null , $tab );
        }
        
        /**
        * Saves the registration tab/area postdata into the tab's permanent storage
        * @param object tab reflecting the tab database entry
        * @param object mosUser reflecting the user being displayed (here null)
        * @param int 1 for front-end, 2 for back-end
        * @param array _POST data for saving edited tab content as generated with getEditTab
        * @return mixed : either string HTML for tab content, or false if ErrorMSG generated
        */
        function saveRegistrationTab($tab, $user, $ui, $postdata) {
                if ( !$this->_checkVirtuemartInstalled() ) return null;
                $this->_saveVirtuemartInfo( $user , true );
        }
        
        /**
        * Called when a user is deleted from backend (prepare future unregistration)
        * @param object tab reflecting the tab database entry
        * @param object mosUser reflecting the user being displayed
        * @param int 1 for front-end, 2 for back-end
        * @returns mixed : either string HTML for tab content, or false if ErrorMSG generated
        */
        function userDeleteTab($user, $success) {
                global $database;
                $q = 'DELETE FROM #__vm_user_info WHERE `user_id` = "'.$user->id.'"';
                $database->setQuery($q);
                $database->query();
        }
        
        // Private method
        // Saves user info
        function _saveVirtuemartInfo( $user , $insert = false ) {
                global $database , $_REQUEST;
                
                // Is in admin section?
                $isAdmin = false;
                if ( substr($_SERVER['REQUEST_URI'],-25) == '/administrator/index2.php' ) $isAdmin = true;

                // Include defined('LEAVE_BANK_DATA') VM config variable
                include_once( _VIRTUEMART_FILE_CONFIG );
                if ( !defined( 'LEAVE_BANK_DATA') ) define( 'LEAVE_BANK_DATA' , 0 );
                
                if ( $insert ) {
                        // Insert record into Virtuemart users
                        $q = 'INSERT INTO #__vm_user_info SET `user_id` = "'. $user->id .'" , `user_info_id` = "'. md5( uniqid( ENCODE_KEY )) .'" , `address_type` = "BT"';
                        $database->setQuery( $q );
                        $database->query();

                        // addition - we also need to add a record to the shopper group table for this user
                        // Prepare default shopper group
                        $q = "SELECT * FROM #__vm_shopper_group WHERE `default`=1";
                        $database->setQuery($q);
                        $database->query();
                        $database->loadObject( $result );
                        $vm_sgi = $result->shopper_group_id;
                        $vm_cn = uniqid( rand() ); // Prepare default customer number
                        $q  = "INSERT INTO #__vm_shopper_vendor_xref ";
                        $q .= 'SET user_id="'.$user->id.'", vendor_id="1", shopper_group_id="'.$vm_sgi.'", customer_number="'.$vm_cn.'"';
                        $database->setQuery( $q );
                        $database->query();
                        }
                // Update virtuemart user record
                $timestamp = time();
                $firstname = '';
                $middlename = '';
                $lastname = '';
                if ( isset($_REQUEST['name']) ) {
                        $space1 = strpos( $_REQUEST['name'] , " " );
                        $space2 = strrpos( $_REQUEST['name'] , " " );
                        if ( $space1 > 0 ) {
                                // Space in name
                                if ( $space1 != $space2 ) {
                                        // More than one space
                                        $firstname = substr( $_REQUEST['name'] , 0 , $space1 );
                                        $middlename = substr( $_REQUEST['name'] , $space1+1 , $space2-$space1 );
                                        $lastname = substr( $_REQUEST['name'] , $space2+1 );
                                } else {
                                        // Only one space
                                        $firstname = substr( $_REQUEST['name'] , 0 , $space1 );
                                        $lastname = substr( $_REQUEST['name'] , $space2+1 );
                                }
                        } else {
                                // No spaces in name
                                $firstname = $_REQUEST['name'];
                        }
                } else {
                        $firstname = $_REQUEST['firstname'];
                        $lastname = $_REQUEST['lastname'];
                        if ( isset($_REQUEST['middlename']) ) {
                                $middlename = $_REQUEST['middlename'];
                        }
                }
                // Make sure we meet the minimal requirements
                if ( $firstname == '' ) $firstname = '.';
                if ( $lastname == '' ) $lastname = '.' ;

                if ( !isset($_REQUEST['perms']) ) {
                $_REQUEST['perms'] = 'shopper'; // set default shopper permission
                }
                
                if ( !isset($_REQUEST['vmart_address_state']) ) {
                        $_REQUEST['vmart_address_state'] = '';
                }
                
                $q = ' UPDATE #__vm_user_info SET '
                                . ' `title` = "'.$_REQUEST['title'] . '"'
                                . ' , `company` = "'.$_REQUEST['vmart_company'] . '"'
                                . ' , `address_1` = "'.$_REQUEST['vmart_address_street'] . '"'
                                . ' , `city` = "'.$_REQUEST['vmart_address_city'] . '"'
                                . ' , `zip` = "'.$_REQUEST['vmart_address_postcode'] . '"'
                                . ' , `country` = "'.$_REQUEST['vmart_address_country'] . '"'
                                . ' , `state` = "'.$_REQUEST['vmart_address_state'] . '"'
                                . ' , `phone_1` = "'.$_REQUEST['vmart_address_phone'] . '"'
                                . ' , `phone_2` = "'.$_REQUEST['vmart_address_mobile'] . '"'
                                . ' , `fax` = "'.$_REQUEST['vmart_address_fax'] . '"'
                                . ' , `first_name` = "'.$firstname . '"'
                                . ' , `middle_name` = "'.$middlename . '"'
                                . ' , `last_name` = "'.$lastname . '"'
                                . ' , `user_email` = "'.$_REQUEST['email'] . '"'
                                . ' , `cdate` = "'. $timestamp . '"'
                                . ' , `mdate` = "'. $timestamp . '"' ;

                if ( defined('LEAVE_BANK_DATA') && LEAVE_BANK_DATA==1 ) {
                        $q .= ' , `bank_account_holder` = "'. $_REQUEST['vmart_bank_holder'] . '"'
                                        . ' , `bank_account_nr` = "'. $_REQUEST['vmart_bank_number'] . '"'
                                        . ' , `bank_sort_code` = "'. $_REQUEST['vmart_bank_code'] . '"'
                                        . ' , `bank_name` = "'. $_REQUEST['vmart_bank_name'] . '"'
                                        . ' , `bank_account_type` = "'. $_REQUEST['vmart_bank_type'] . '"'
                                        . ' , `bank_iban` = "'. $_REQUEST['vmart_bank_iban'] . '"' ;
                }

                // Include perms data if sent from admin section
                if ( $isAdmin ) {
                        $q .= ' , `perms` = "'. $_REQUEST['perms'] . '"';
                }

                $q .= ' WHERE `user_id` = "' . $user->id . '" AND `address_type` = "BT" ';
                $database->setQuery( $q );
                $database->query();
                
                if ( $isAdmin ) {
                        // If in admin section, do shopper-group stuff
                        
                        $vendor_id = 1; // When VM vendor function becomes live, update this
                        $q = "SELECT * FROM #__vm_shopper_vendor_xref WHERE `vendor_id`=".$vendor_id." AND `user_id`=" . $user->id;
                        $database->setQuery($q);
                        $database->query();

                        // Prepare default shopper group
                        $q = "SELECT * FROM #__vm_shopper_group WHERE `default`=1";
                        $database->setQuery($q);
                        $database->query();
                        $database->loadObject( $result );
                        $default_vm_sgi = $result->shopper_group_id;
                        // Prepare default customer number
                        $default_vm_cn = uniqid( rand() );

                        $vm_sgi = $_REQUEST['vmart_shopper_group_id'];
                        $vm_cn = $_REQUEST['vmart_customer_number'];
                        if ( strlen($vm_sgi)==0 ) $vm_sgi=$default_vm_sgi;
                        if ( strlen($vm_cn)==0 ) $vm_cn=$default_vm_cn;
                        if( sizeof($database->loadRowList()) < 1 ) {
                                // Insert Shopper -ShopperGroup - Relationship
                                $q  = "INSERT INTO #__vm_shopper_vendor_xref ";
                                $q .= 'SET user_id="'.$user->id.'", vendor_id="'.$vendor_id.'", shopper_group_id="'.$vm_sgi.'", customer_number="'.$vm_cn.'"';
                        }
                        else {
                                // Update the Shopper Group Entry for this user
                                $q = "UPDATE #__vm_shopper_vendor_xref SET ";
                                $q .= "`shopper_group_id`=".$vm_sgi." ";
                                $q.= ",`vendor_id`=".$vendor_id." ";
                                $q.= ",`customer_number`=".$vm_cn." ";
                                $q .= "WHERE `user_id`=" . $user->id;
                        }
                        $database->setQuery($q);
                        $database->query();
                }
                
                return true;
        }
        
        // Private method
        // Displays user info
        function _showVirtuemartInfo( $user = null , $tab = null ) {

                include_once( _VIRTUEMART_FILE_PERM );
                include_once( _VIRTUEMART_FILE_HTML );
                include_once( _VIRTUEMART_FILE_ABSTRACT_OBJECT );
                include_once( _VIRTUEMART_FILE_SHOPPER_GROUP );
                include_once( _VIRTUEMART_FILE_USER );
                include_once( _VIRTUEMART_FILE_DATABASE );
                include_once( _VIRTUEMART_FILE_LANGUAGE );
                //include_once( _VIRTUEMART_FILE_ENGLISH );
                include_once( _VIRTUEMART_FILE_CONFIG );
                include_once( _VIRTUEMART_FILE_MAIN );
                include_once( _VIRTUEMART_FILE_MAINFRAME );

                $vmart_html = new ps_html();

                if ( defined('_CB_VIRTUEMART_REGISTER_FROM_VM') ) { 
                        // Use the loaded language file
                        global $VM_LANG;
                        $vmart_lang = $VM_LANG;
                        // Set our return URL to be the checkout
                        $_REQUEST['return']=urlencode( _CB_VIRTUEMART_REGISTER_FROM_VM_RETURN );
                } else {
                        //$vmart_lang = $VM_LANG;
                        //global $VM_LANG;
                        //$VM_LANG = $vmart_lang;
                }

global $VM_LANG;
if ( !is_object($VM_LANG) ) $VM_LANG = $GLOBALS['PHPSHOP_LANG'] =& new vmLanguage();
// loading common language module
$VM_LANG->load('common');
$VM_LANG->load('store');

global $vm_mainframe;
$vm_mainframe = new vmMainFrame();

                $vm_title = '';
                $vm_company = '';
                $vm_address_street = '';
                $vm_address_city = '';
                $vm_address_postcode = '';
                $vm_address_country = '';
                $vm_address_state = '';
                $vm_address_phone = '';
                $vm_address_mobile = '';
                $vm_address_fax = '';
                $vm_bank_holder = '';
                $vm_bank_number = '';
                $vm_bank_code = '';
                $vm_bank_name = '';
                $vm_bank_type = '';
                $vm_bank_iban = '';
                $vm_perms = '';
                $pad = '';
                
                $rv = '';
                
                // Handle our required/optional/hidden preference for user rego fields
                $regoRequired = $this->params->get('regoFieldsRequired' , 1);
                $regoHidden = !$this->params->get('regoFieldsShow' , 1);
                
                // If we are showing this page on a reload (due to a Joomla error for example), populate the fields
                if ( isset($_REQUEST['vmart_company']) ) $vm_company = $_REQUEST['vmart_company'];
                if ( isset($_REQUEST['title']) ) $vm_title = $_REQUEST['title'];
                if ( isset($_REQUEST['vmart_address_street']) ) $vm_address_street = $_REQUEST['vmart_address_street'];
                if ( isset($_REQUEST['vmart_address_city']) ) $vm_address_city = $_REQUEST['vmart_address_city'];
                if ( isset($_REQUEST['vmart_address_postcode']) ) $vm_address_postcode = $_REQUEST['vmart_address_postcode'];
                if ( isset($_REQUEST['vmart_address_country']) ) $vm_address_country = $_REQUEST['vmart_address_country'];
                if ( isset($_REQUEST['vmart_address_state']) ) $vm_address_state = $_REQUEST['vmart_address_state'];
                if ( isset($_REQUEST['vmart_address_phone']) ) $vm_address_phone = $_REQUEST['vmart_address_phone'];
                if ( isset($_REQUEST['vmart_address_mobile']) ) $vm_address_mobile = $_REQUEST['vmart_address_mobile'];
                if ( isset($_REQUEST['vmart_address_fax']) ) $vm_address_fax = $_REQUEST['vmart_address_fax'];
                if ( isset($_REQUEST['vmart_bank_holder']) ) $vm_bank_holder = $_REQUEST['vmart_bank_holder'];
                if ( isset($_REQUEST['vmart_bank_number']) ) $vm_bank_number = $_REQUEST['vmart_bank_number'];
                if ( isset($_REQUEST['vmart_bank_code']) ) $vm_bank_code = $_REQUEST['vmart_bank_code'];
                if ( isset($_REQUEST['vmart_bank_name']) ) $vm_bank_name = $_REQUEST['vmart_bank_name'];
                if ( isset($_REQUEST['vmart_bank_type']) ) $vm_bank_type = $_REQUEST['vmart_bank_type'];
                if ( isset($_REQUEST['vmart_bank_iban']) ) $vm_bank_iban = $_REQUEST['vmart_bank_iban'];
                
                // Were we passed a return variable?
                if ( isset( $_REQUEST['return'] ) ) $rv .= '<input type="hidden" name="return" value="'.urldecode($_REQUEST['return']).'" />';
                
                // Is in admin section?
                $isAdmin = false;
                if ( substr($_SERVER['REQUEST_URI'],-25) == '/administrator/index2.php' ) $isAdmin = true;

                if ( $user != null ) {
                        global $database;
                        $q = 'SELECT * FROM #__vm_user_info WHERE `user_id` = "'.$user->id.'"';
                        $database->setQuery($q);
                        $database->loadObject( $row );
                        
                        $vm_title = $row->title;
                        $vm_company = $row->company;
                        $vm_address_street = $row->address_1;
                        $vm_address_city = $row->city;
                        $vm_address_postcode = $row->zip;
                        $vm_address_country = $row->country;
                        $vm_address_state = $row->state;
                        $vm_address_phone = $row->phone_1;
                        $vm_address_mobile = $row->phone_2;
                        $vm_address_fax = $row->fax;
                        
                        $vm_bank_holder = $row->bank_account_holder;
                        $vm_bank_number = $row->bank_account_nr;
                        $vm_bank_code = $row->bank_sort_code;
                        $vm_bank_name = $row->bank_name;
                        $vm_bank_type = $row->bank_account_type;
                        $vm_bank_iban = $row->bank_iban;
                        
                        $pad = '&nbsp;';
                }

                // If we're hiding from the user, do so now
                // Only show if: we are not hiding rego OR we are editing not registering
                if ( !$regoHidden || $user!=null ) {
        
                        $hideTitle=$this->params->get('hideTitle' , 0);
                        if ( $user == null && !$hideTitle ) {
                                $rv .= '<tr><th colspan="2" class="titleCell">';
                                $myTitle = _VIRTUEMART_TITLE;
                                if ( $tab != null ) $myTitle = $tab->title;
                                $rv .= '<hr />'. $myTitle .'<hr />';
                                $rv .= '</th></tr>';
                        }
                        
                        if ( $user != null ) {
                                if($tab->description != null) $rv .= "<tr><td colspan=2>".unHtmlspecialchars(getLangDefinition($tab->description))."</td></tr>";
                        }
                        
                        $showUserTitle=$this->params->get('showUserTitle' , 1);
                        if ( $showUserTitle ) {
                                $rv .= '<tr><th class="titleCell">' . $pad . $VM_LANG->_('PHPSHOP_USER_FORM_TITLE') . '</th>';
                                $rv .= '<td class="fieldCell">';
                                ob_start();
                                $vmart_html->list_user_title($vm_title);
                                $rv .= ob_get_contents();
                                ob_end_clean();
                                $rv .= getFieldIcons(1,false,false,$VM_LANG->_('PHPSHOP_USER_FORM_TITLE'),$VM_LANG->_('PHPSHOP_USER_FORM_TITLE'));
                                $rv .= '</td></tr>';
                        }
        
                        $rv .= '<tr><th class="titleCell">' . $pad . $VM_LANG->_('PHPSHOP_USER_FORM_COMPANY_NAME') . '</th>';
                        $rv .= '<td class="fieldCell"><input mosReq="0" class="inputbox" name="vmart_company" type="text" size="40" maxlength="64" value="'.$vm_company.'" />';
                        $rv .= getFieldIcons(1,false,false,$VM_LANG->_('PHPSHOP_USER_FORM_COMPANY_NAME'),$VM_LANG->_('PHPSHOP_USER_FORM_COMPANY_NAME'));
                        $rv .= '</td></tr>';
        
                        $rv .= '<tr><th class="titleCell">' . $pad . $VM_LANG->_('PHPSHOP_USER_FORM_ADDRESS_1') . '</th>';
                        $rv .= '<td class="fieldCell"><input mosReq="'.$regoRequired.'" mosLabel="'.$VM_LANG->_('PHPSHOP_USER_FORM_ADDRESS_1') .': " class="inputbox" name="vmart_address_street" type="text" size="40" maxlength="64" value="'.$vm_address_street.'" />';
                        $rv .= getFieldIcons(1,$regoRequired,false,$VM_LANG->_('PHPSHOP_USER_FORM_ADDRESS_1'),$VM_LANG->_('PHPSHOP_USER_FORM_ADDRESS_1'));
                        $rv .= '</td></tr>';
        
                        $rv .= '<tr><th class="titleCell">' . $pad . $VM_LANG->_('PHPSHOP_USER_FORM_CITY') . '</th>';
                        $rv .= '<td class="fieldCell"><input mosReq="'.$regoRequired.'" mosLabel="'.$VM_LANG->_('PHPSHOP_USER_FORM_CITY') .': "class="inputbox" name="vmart_address_city" type="text" size="40" maxlength="32" value="'.$vm_address_city.'" />';
                        $rv .= getFieldIcons(1,$regoRequired,false,$VM_LANG->_('PHPSHOP_USER_FORM_CITY'),$VM_LANG->_('PHPSHOP_USER_FORM_CITY'));
                        $rv .= '</td></tr>';
        
                        $rv .= '<tr><th class="titleCell">' . $pad . $VM_LANG->_('PHPSHOP_USER_FORM_ZIP') . '</th>';
                        $rv .= '<td class="fieldCell"><input mosReq="'.$regoRequired.'" mosLabel="'.$VM_LANG->_('PHPSHOP_USER_FORM_ZIP') .': "class="inputbox" name="vmart_address_postcode" type="text" size="40" maxlength="32" value="'.$vm_address_postcode.'" />';
                        $rv .= getFieldIcons(1,$regoRequired,false,$VM_LANG->_('PHPSHOP_USER_FORM_ZIP'),$VM_LANG->_('PHPSHOP_USER_FORM_ZIP'));
                        $rv .= '</td></tr>';
        
                        $rv .= '<tr><th class="titleCell">' . $pad . $VM_LANG->_('PHPSHOP_USER_FORM_COUNTRY') . '</th>';
                        $rv .= '<td class="fieldCell">';
                        ob_start();
                        
                        $onchange = "onchange=\"changeStateList();\"";
                
                        $onchange .= ' mosReq="'.$regoRequired.'" mosLabel="'.$VM_LANG->_('PHPSHOP_USER_FORM_COUNTRY').'" ';
                        $vmart_html->list_country( 'vmart_address_country' , $vm_address_country , "id=\"country_field\" $onchange" );
                        $rv .= ob_get_contents();
                        ob_end_clean();
                        $rv .= getFieldIcons(1,$regoRequired,false,$VM_LANG->_('PHPSHOP_USER_FORM_COUNTRY'),$VM_LANG->_('PHPSHOP_USER_FORM_COUNTRY'));
                        $rv .= '</td></tr>';
        
                        
                                $rv .= '<tr><th class="titleCell">' . $pad . $VM_LANG->_('PHPSHOP_USER_FORM_STATE') . '</th>';
                                $rv .= '<td class="fieldCell">';
                                $rv .= $vmart_html->dynamic_state_lists( 'vmart_address_country' , 'vmart_address_state' , $vm_address_country , $vm_address_state );
                                ob_start();
                                echo "<noscript>\n";
                                $vmart_html->list_states( "vmart_address_state" , $vm_address_state , "" , "id=\"state\" " );
                                echo "</noscript>\n";
                                $rv .= ob_get_contents();
                                ob_end_clean();
                                $rv .= getFieldIcons(1,false,false,$VM_LANG->_('PHPSHOP_USER_FORM_STATE'),$VM_LANG->_('PHPSHOP_USER_FORM_STATE'));
                                $rv .= '</td></tr>';
                        
        
                        $rv .= '<tr><th class="titleCell">' . $pad . $VM_LANG->_('PHPSHOP_USER_FORM_PHONE') . '</th>';
                        $rv .= '<td class="fieldCell"><input mosReq="'.$regoRequired.'" mosLabel="'.$VM_LANG->_('PHPSHOP_USER_FORM_PHONE') .': " class="inputbox" name="vmart_address_phone" type="text" size="40" maxlength="32" value="'.$vm_address_phone.'" />';
                        $rv .= getFieldIcons(1,$regoRequired,false,$VM_LANG->_('PHPSHOP_USER_FORM_PHONE'),$VM_LANG->_('PHPSHOP_USER_FORM_PHONE'));
                        $rv .= '</td></tr>';
        
                        $rv .= '<tr><th class="titleCell">' . $pad . $VM_LANG->_('PHPSHOP_USER_FORM_PHONE2') . '</th>';
                        $rv .= '<td class="fieldCell"><input class="inputbox" name="vmart_address_mobile" type="text" size="40" maxlength="32" value="'.$vm_address_mobile.'" />';
                        $rv .= getFieldIcons(1,false,false,$VM_LANG->_('PHPSHOP_USER_FORM_PHONE2'),$VM_LANG->_('PHPSHOP_USER_FORM_PHONE2'));
                        $rv .= '</td></tr>';
        
                        $rv .= '<tr><th class="titleCell">' . $pad . $VM_LANG->_('PHPSHOP_USER_FORM_FAX') . '</th>';
                        $rv .= '<td class="fieldCell"><input class="inputbox" name="vmart_address_fax" type="text" size="40" maxlength="32" value="'.$vm_address_fax.'" />';
                        $rv .= getFieldIcons(1,false,false,$VM_LANG->_('PHPSHOP_USER_FORM_FAX'),$VM_LANG->_('PHPSHOP_USER_FORM_FAX'));
                        $rv .= '</td></tr>';
                        
                        $showShipping = $this->params->get('showShipping' , 1);
                        
                        if ( $user != null && $showShipping ) {
                                // Shipping options
                                $rv .= '<tr><th class="titleCell">&nbsp;</th></tr>';
                                $rv .= '<tr><th class="titleCell">' . $pad . $VM_LANG->_('PHPSHOP_USER_FORM_SHIPTO_LBL') . '</th>';
                                $rv .= '<td class="fieldCell">';
                                if (!$isAdmin) $rv .= '<a href="index.php?option=com_virtuemart&page=account.shipping&Itemid='.$GLOBALS['Itemid'].'">';
                                if (!$isAdmin) $rv .= _CB_VIRTUEMART_EDIT_SHIPPING_LINK ;
                                $q = 'SELECT * FROM #__vm_user_info WHERE `user_id` = "'.$user->id.'" AND `address_type` = "ST" ';
                                $database->setQuery($q);
                                $database->query();
                                $rv .= ' (' . $database->getNumRows() . ' '._CB_VIRTUEMART_EDIT_SHIPPING_DEFINED.')';
                                if (!$isAdmin) $rv .= '</a>';
                                $rv .= getFieldIcons(1,false,false,$VM_LANG->_('PHPSHOP_USER_FORM_SHIPTO_LBL'),$VM_LANG->_('PHPSHOP_USER_FORM_SHIPTO_LBL'));
                                $rv .= '</td></tr>';
                        }
                        
                        if ( defined('LEAVE_BANK_DATA')  && LEAVE_BANK_DATA==1 ) {
                                $rv .= '<tr><th class="titleCell">&nbsp;</th></tr>';
                                $rv .= '<tr><th class="titleCell" colspan="2">' . $pad . $VM_LANG->_('PHPSHOP_ACCOUNT_BANK_TITLE') . '</th></tr>';
        
                                $rv .= '<tr><th class="titleCell">' . $pad . $VM_LANG->_('PHPSHOP_ACCOUNT_LBL_BANK_ACCOUNT_HOLDER') . '</th>';
                                $rv .= '<td class="fieldCell"><input mosReq="'.$regoRequired.'" mosLabel="'.$VM_LANG->_('PHPSHOP_ACCOUNT_LBL_BANK_ACCOUNT_HOLDER') .': " class="inputbox" name="vmart_bank_holder" type="text" size="40" maxlength="32" value="'.$vm_bank_holder.'" />';
                                $rv .= getFieldIcons(1,$regoRequired,false,$VM_LANG->_('PHPSHOP_ACCOUNT_LBL_BANK_ACCOUNT_HOLDER'),$VM_LANG->_('PHPSHOP_ACCOUNT_LBL_BANK_ACCOUNT_HOLDER'));
                                $rv .= '</td></tr>';
        
                                $rv .= '<tr><th class="titleCell">' . $pad . $VM_LANG->_('PHPSHOP_ACCOUNT_LBL_BANK_ACCOUNT_NR') . '</th>';
                                $rv .= '<td class="fieldCell"><input mosReq="'.$regoRequired.'" mosLabel="'.$VM_LANG->_('PHPSHOP_ACCOUNT_LBL_BANK_ACCOUNT_NR') .': " class="inputbox" name="vmart_bank_number" type="text" size="40" maxlength="32" value="'.$vm_bank_number.'" />';
                                $rv .= getFieldIcons(1,$regoRequired,false,$VM_LANG->_('PHPSHOP_ACCOUNT_LBL_BANK_ACCOUNT_NR'),$VM_LANG->_('PHPSHOP_ACCOUNT_LBL_BANK_ACCOUNT_NR'));
                                $rv .= '</td></tr>';
        
                                $rv .= '<tr><th class="titleCell">' . $pad . $VM_LANG->_('PHPSHOP_ACCOUNT_LBL_BANK_SORT_CODE') . '</th>';
                                $rv .= '<td class="fieldCell"><input mosReq="'.$regoRequired.'" mosLabel="'.$VM_LANG->_('PHPSHOP_ACCOUNT_LBL_BANK_SORT_CODE') .': " class="inputbox" name="vmart_bank_code" type="text" size="40" maxlength="32" value="'.$vm_bank_code.'" />';
                                $rv .= getFieldIcons(1,$regoRequired,false,$VM_LANG->_('PHPSHOP_ACCOUNT_LBL_BANK_SORT_CODE'),$VM_LANG->_('PHPSHOP_ACCOUNT_LBL_BANK_SORT_CODE'));
                                $rv .= '</td></tr>';
        
                                $rv .= '<tr><th class="titleCell">' . $pad . $VM_LANG->_('PHPSHOP_ACCOUNT_LBL_BANK_NAME') . '</th>';
                                $rv .= '<td class="fieldCell"><input mosReq="'.$regoRequired.'" mosLabel="'.$VM_LANG->_('PHPSHOP_ACCOUNT_LBL_BANK_NAME') .': " class="inputbox" name="vmart_bank_name" type="text" size="40" maxlength="32" value="'.$vm_bank_name.'" />';
                                $rv .= getFieldIcons(1,$regoRequired,false,$VM_LANG->_('PHPSHOP_ACCOUNT_LBL_BANK_NAME'),$VM_LANG->_('PHPSHOP_ACCOUNT_LBL_BANK_NAME'));
                                $rv .= '</td></tr>';
        
                                $rv .= '<tr><th class="titleCell">' . $pad . $VM_LANG->_('PHPSHOP_ACCOUNT_LBL_ACCOUNT_TYPE') . '</th>';
                                $rv .= '<td class="fieldCell">';
                                $selected[0] = '';
                                $selected[1] = '';
                                $selected[2] = '';
                                if ( $vm_bank_type == "Checking" ) $selected[0] = " SELECTED ";
                                if ( $vm_bank_type == "Business Checking" ) $selected[1] = " SELECTED ";
                                if ( $vm_bank_type == "Savings" ) $selected[2] = " SELECTED ";
                                $rv .= '<select mosReq="'.$regoRequired.'" mosLabel="'.$VM_LANG->_('PHPSHOP_ACCOUNT_LBL_ACCOUNT_TYPE') .': " class="inputbox" name="vmart_bank_type">
                                        <option '. $selected[0] .' value="Checking">'. $VM_LANG->_('PHPSHOP_ACCOUNT_LBL_ACCOUNT_TYPE_CHECKING') .'</option>
                                        <option '. $selected[1] .' value="Business Checking">'. $VM_LANG->_('PHPSHOP_ACCOUNT_LBL_ACCOUNT_TYPE_BUSINESSCHECKING') .'</option>
                                        <option '. $selected[2] .' value="Savings">'. $VM_LANG->_('PHPSHOP_ACCOUNT_LBL_ACCOUNT_TYPE_SAVINGS') .'</option>
                                        </select>';
                                $rv .= getFieldIcons(1,$regoRequired,false,$VM_LANG->_('PHPSHOP_ACCOUNT_LBL_ACCOUNT_TYPE'),$VM_LANG->_('PHPSHOP_ACCOUNT_LBL_ACCOUNT_TYPE'));
                                $rv .= '</td></tr>';
        
                                $rv .= '<tr><th class="titleCell">' . $pad . $VM_LANG->_('PHPSHOP_ACCOUNT_LBL_BANK_IBAN') . '</th>';
                                $rv .= '<td class="fieldCell"><input mosReq="'.$regoRequired.'" mosLabel="'.$VM_LANG->_('PHPSHOP_ACCOUNT_LBL_BANK_IBAN') .': " class="inputbox" name="vmart_bank_iban" type="text" size="40" maxlength="32" value="'.$vm_bank_iban.'" />';
                                $rv .= getFieldIcons(1,$regoRequired,false,$VM_LANG->_('PHPSHOP_ACCOUNT_LBL_BANK_IBAN'),$VM_LANG->_('PHPSHOP_ACCOUNT_LBL_BANK_IBAN'));
                                $rv .= '</td></tr>';
                                                        
                        }
                        
                        // Show a gap at the bottom?
                        $showGap=$this->params->get('showGap' , 1);
                        if ( $showGap ) {
                                $rv .= '<tr><td>&nbsp;</td></tr>';
                        }

                }

                return $rv;
        }
        
        // Private Method:
        /**
        * Checks if virtuemart component installed
        * @return boolean true =installed, false = not
        */
        function _checkVirtuemartInstalled() {
        
                global $database, $mosConfig_absolute_path;
                
                // Check that main admin file exists
                if( !file_exists( _VIRTUEMART_FILE_HTML ) ) {
                        return false;
                }
                
                // Check that DB exists
                $query = "SELECT COUNT( * ) FROM #__components WHERE link LIKE '%com_virtuemart%'";
                $database->setQuery( $query );
                if ($database->LoadResult() < 1) {
                        return false;
                }
                
                return true;
        }
        
        /*
        function postRegoLogin( $row , $activated = true ) {
                
                // If we were not activated, exit this function now
                if ( !$activated ) return;
                
                // Get the default setting
                $afterRegoLogin = $this->params->get('afterRegoLogin' , 1);
                // If we set this to 'no', don't do anything in this function
                if ( !$afterRegoLogin ) return;

                // Are we using a joomla which supports josSpoofValue?
                if ( is_callable( 'josSpoofValue' ) ) {
                        // Setup the jos spoof value that's expected
                        $_POST[ josSpoofValue() ] = 1;
                }
                // The 1.0.12 bugfix (copied from mod_cblogin)
                $_POST[ 'forceSession' ] = 1;
                
                // Now log the user in
                login( $row->username , $row->password );
        }
        */
        
} // end class getNewslettersTab.

// Install function
function plug_Virtuemart_install() {
        return _CB_VIRTUEMART_INSTALL;  
}

// Uninstall function
function plug_Virtuemart_uninstall() {
        return _CB_VIRTUEMART_UNINSTALL;        
}

include( 'virtuemart-includes.php' );

?>
